#
# spec file for package ed
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ed
Version:        1.17
Release:        150400.1.5
Summary:        A line-oriented text editor
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Text/Editors
URL:            https://www.gnu.org/software/ed/
# This is just recompressed from  http://ftp.gnu.org/gnu/ed/ed-%{version}.tar.lz
# in order to avoid pulling lzip to ring0
Source0:        ed-%{version}.tar.xz
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
GNU ed is a line-oriented text editor. It is used to create, display,
modify and otherwise manipulate text files, both interactively and via
shell scripts. A restricted version of ed, red, can only edit files in
the current directory and cannot execute shell commands. Ed is the
"standard" text editor in the sense that it is the original editor for
Unix, and thus widely available. For most purposes, however, it is
superseded by full-screen editors such as GNU Emacs or GNU Moe.

%prep
%setup -q

%build
%configure
%make_build CFLAGS="%{optflags}"

%install
%make_install
%if !0%{?usrmerged}
install -d -m 0755 %{buildroot}/bin
ln -s %{_bindir}/ed %{buildroot}/bin/ed
%endif

%check
%make_build check

%post
%install_info --entry="* ed: (ed). Line-oriented text editor" --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%if !0%{?usrmerged}
/bin/%{name}
%endif
%{_bindir}/%{name}
%{_bindir}/r%{name}
%{_infodir}/%{name}.info%{?ext_info}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/r%{name}.1%{?ext_man}

%changelog
* Mon Jan 25 2021 info@paolostivanin.com
- Update to 1.17
  * The commands 'q' and 'Q' now work in a global command.
  * The new option '-E, --extended-regexp' has been added. It tells
    ed to use extended regular expressions instead of the basic
    regular expressions mandated by POSIX
  * Print the file name in case of read or write error
* Fri Oct 16 2020 lnussel@suse.de
- prepare usrmerge (boo#1029961)
* Tue Mar  3 2020 info@paolostivanin.com
- Update to 1.16
  * regex.c (line_replace): Accept 's/^/#/g' as valid.
    (Reported by Bjoern Wibben).
  * main_loop.c: Removed length limit of prompt string.
    (Reported by Tim Chase).
  * main.c: Set a valid invocation_name even if argc == 0.
  * ed.texi: Extended operators depend on regex implementation.
    (Reported by Brian Zwahr).
  * ed.texi: Several fixes and improvements.
* Thu Jan 10 2019 tchvatal@suse.com
- Switch back to hand provided tarball in order to avoid pulling
  lzip to the Ring0
* Mon Jan  7 2019 tchvatal@suse.com
- Use upstream released tarball
* Fri Jan  4 2019 jengelh@inai.de
- Avoid repetition of package name in summary.
* Thu Jan  3 2019 sean@suspend.net
- Update to version 1.15:
  * io.c (print_line): Make '1' command print '\\' before every
    '$' within the text.
  * main_loop.c (extract_addresses): Fixed address ',,' to mean
    '$,$' instead of '1,$'.
  * regex.c (extract_replacement): Allow newlines even if global.
  * main_loop.c (exec_command): Make 'c' command reject address 0.
  * ed.texi: Minor fixes.
  * configure: Accept appending to CFLAGS, 'CFLAGS+=OPTIONS'.
  * Switch archive format to tar.
* Sat Feb 25 2017 mpluskal@suse.com
- Update to version 1.14.2:
  * main.c (show_strerror) Revert to using '!scripted' instead of
  'verbose' to suppress diagnostics.
  * Print counts, messages, '?' and '!' to stdout instead of stderr.
  * buffer.c (append_lines): Fixed current address after empty 'i'.
  * regex.c (set_subst_regex): Treat missing delimiters consistently.
  (extract_replacement): Don't replace 'a' with '%%' in 's/a/%%'.
  Fixed infinite loop with EOF in the middle of a replacement.
  Don't accept newlines in replacement in a global command.
  Last delimiter can't be omitted if not last in command list.
  (search_and_replace): Set current address to last line modified.
  * main_loop.c (extract_addresses): Fixed address offsets;
  '3 ---- 2' was calculated as -2 instead of 1.
  Accept ranges with the first address omitted.
  (exec_command): Fixed current address after empty replacement
  text in 'c' command.
  Don't clear the modified status after writing the buffer to a
  shell command. (Reported by Jérôme Frgacic).
  (get_command_suffix): Don't allow repeated print suffixes.
  (command_s): Accept suffixes in any order.
  Don't allow multiple count suffixes.
  'sp' now toggles all print suffixes.
  (main_loop): Make EOF on stdin behave as a 'q' command.
  * ed.texi: Fixed the description of commands 'acegijkmqrsuw'.
  Documented that ed allows any combination of print suffixes.
  * testsuite: Improved most tests. Simplified bug reporting.
  * configure: Avoid warning on some shells when testing for gcc.
  * Makefile.in: Detect the existence of install-info.
* Sat Jan  7 2017 mpluskal@suse.com
- Update to version 1.14:
  * Print counts, messages, '?' and '!' to stdout instead of stderr.
  * buffer.c (append_lines): Fixed current address after empty 'i'.
  * regex.c (set_subst_regex): Treat missing delimiters consistently.
  * (extract_replacement): Don't replace 'a' with '%%' in 's/a/%%'.
  * Fixed infinite loop with EOF in the middle of a replacement.
  * Don't accept newlines in replacement in a global command.
  * Last delimiter can't be omitted if not last in command list.
  * (search_and_replace): Set current address to last line modified.
  * main_loop.c (extract_addresses): Fixed address offsets;
  * '3 ---- 2' was calculated as -2 instead of 1.
  * Accept ranges with the first address omitted.
  * (exec_command): Fixed current address after empty replacement
  text in 'c' command.
  * Don't clear the modified status after writing the buffer to a
  shell command. (Reported by Jérôme Frgacic).
  * (get_command_suffix): Don't allow repeated print suffixes.
  * (command_s): Accept suffixes in any order.
  * Don't allow multiple count suffixes.
  * 'sp' now toggles all print suffixes.
  * (main_loop): Make EOF on stdin behave as a 'q' command.
  * ed.texi: Fixed the description of commands 'acegijkmqrsuw'.
  * Documented that ed allows any combination of print suffixes.
  * testsuite: Improved most tests. Simplified bug reporting.
  * configure: Avoid warning on some shells when testing for gcc.
  * Makefile.in: Detect the existence of install-info.
* Fri Feb 12 2016 mpluskal@suse.com
- Update to 1.13
  * buffer.c (put_sbuf_line): Fixed a memory leak.
  * io.c (read_file, write_file): Close file on error.
* Sat Jul 11 2015 mpluskal@suse.com
- Update to 1.12
  * ed.texi: Removed extra spaces from some commands.
* Fri Apr  3 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update to 1.11
  * main_loop.c (exec_command): Fixed 'z' command.
    (zN printed N + 1 lines).
  * ed.texi: Documented the window size used by the 'z' command.
  * Makefile.in: Added new targets 'install*-compress'.
  * Restored original copyright notices in the code. I assigned to
    the FSF the copyright on changes made to the part of ed already
    copyrighted by the FSF, which seems to be just the manual.
* Fri Feb 21 2014 mvyskocil@suse.com
- update to 1.10
  + "ed.texinfo" has been renamed to "ed.texi" following the advice
  of recent Automake about obsolete categories
- repackage tarball to xz as lzip is unlike ed not a part of bootstrap
- drop xz and keyring, they are pointless with changed tarball
* Tue Jul 16 2013 mvyskocil@suse.com
- update to 1.9
  + Testsuite no more feeds shell scripts to ed.
  + "configure" now accepts options with a separate argument.
* Mon Jun 17 2013 coolo@suse.com
- revert the use gpg-offline for bootstrap packages
* Fri Apr 26 2013 mvyskocil@suse.com
- update to 1.8
  + Ed now stops reading stdin when reaching real End Of File the first
    time. (Before it needed to reach EOF twice).
  + Show the "Try 'ed --help' for more information." message if a bad
    option is given in the command line.
  + Quote characters in messages have been changed as advised by GNU
    Coding Standards.
  + The description of address offsets in the manual and a link to the
    Bash manual have been fixed.
  + Displaying of null characters by the "l" command has been fixed.
  + The condition deciding when to show the message "Newline appended" has
    been corrected.
  + The "modified" flag is now set when reading a non-empty file into
    an empty buffer.
  + An error that prevented using NUL characters in regular expressions
    has been fixed.
  + Ed now signals an error if it can't create a shell process when
    executing a shell command.
  + Ed now flushes stdout/stderr before reading a new command.
  + Man page is now generated with "help2man". All command-line options
    are now documented in the man page.
- use gpg-offline to verify the package tarball
- adapt the Summary and Description according current README
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Oct 23 2012 cfarrell@suse.com
- license update: GPL-3.0+ and LGPL-2.1+
  Semicolon is ambiguous
* Fri Feb  3 2012 rschweikert@suse.com
- switch license to spdx format
- keep executable in /usr (UsrMerge project)
* Mon Jan  2 2012 dlovasko@suse.com
- Update to 1.6 (bugfix release)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 1.5:
  + The "a", "c" and "i" commands have been fixed. (When used in a
    global command list, the commands following them in the list
    were ignored).
  + The "e" command has been fixed. (It quitted when invoked a
    second time with a modified buffer).
  + The new option "--restricted" has been added.
  + "red" has been converted to a script invoking "ed
  - -restricted".
  + Description of ed in the manual has been changed.
  + Obsolete posix tests have been removed from testsuite.
- Remove AutoReqProv: it's default now.
* Mon Nov 30 2009 mvyskocil@suse.cz
- updated to latest upstream version 1.4 - major rewrite and bugfixes (see
  Changelog for details)
- obsoleted all patches
* Fri Oct 20 2006 lrupp@suse.de
- revert to 0.2: new version is broken (#212749)
* Mon Oct  9 2006 agruen@suse.de
- dash-option.diff: Fix `ed - filename' invocation.
* Mon Oct  9 2006 schwab@suse.de
- Update to ed 0.3-pre2.
  * The symlink vulnerability has been fixed using the "tmpfile" function.
  * The manual has been updated.
  * An extensive code cleanup has been done.
- Fix signal handing again.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct  1 2004 schwab@suse.de
- Fix signal handling
  (<http://lists.gnu.org/archive/html/bug-gnu-utils/2004-09/msg00123.html>).
* Fri Sep 10 2004 schwab@suse.de
- Don't use __P from glibc headers.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr 15 2003 coolo@suse.de
- use BuildRoot
* Mon Mar  3 2003 ro@suse.de
- fixed typo in dir entry
* Mon Mar  3 2003 ro@suse.de
- added info dir entry
* Fri Feb  7 2003 ro@suse.de
- use install_info macros
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Dec 19 2000 werner@suse.de
- Close temporary file security hole
* Fri Feb 25 2000 kukuk@suse.de
- Use RPM_OPT_FLAGS
- Move /usr/{info,man} -> /usr/share/{info,man}
* Sat Nov  6 1999 bs@suse.de
- moved binary to /bin/ed and provide symlink /usr/bin/ed
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
